<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ye Software Llibre pero lleva un tiempu valoratible desendolcalu.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;fai una donación&lt;/a&gt; pa sofitar el desendolcu continuu de %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Asoleyáu baxo la &lt;a href=&apos;%1&apos;&gt;Llicencia Pública Xeneral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zarrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tocante a</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Lo que siempres quixisti saber sobro %1 y nun t&apos;atrevíes a entrugar</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Seique quieras probar tamién les mios otres aplicaciones:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, una aplicación pa YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, un reproductor de musica de YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduz %1 a la to llingua llariega usando %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Con llicencia pa: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Escriba los detalles de la llicencia</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>Corréu &amp;electrónicu:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Códigu:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Por favor, merca una llicencia de %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demo caducó.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Ensin llicencia, l&apos;aplicación caducará en %1 díes.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Al comprar la versión completa, tamién sofites el duru trabayu que punxi pa crear %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar la demostración</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Escriba la llicencia</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Mercar una llicencia</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>La versión completa permite amestar más de %1 pistes a la llista de reproducción y sentir la música ensin cortes.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Mercar en %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Lleer más</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Añu</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularidá</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Orde inversu</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Lleer más</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Númberu de pistes</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Númberu d&apos;álbumes</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Añu</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularidá</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Orde inversu</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Dir atrás</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienveníu a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 necesita analizar la coleición de música.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Usar la coleición d&apos;iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Usar %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Escueyi una carpeta...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 coneutará colos servicios web de Last.fm y pasará-y los nomes d&apos;artistes y títulos d&apos;álbumes pa baxar imaxes de portaes, biografíes y muncho más.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Si t&apos;esmolez la to intimidá darréu d&apos;esto, pues colar agora.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>¿Ú tienes la to coleición de música?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Seleiciona el llugar onde ta la to coleición de música</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Llocaliza la to coleición</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Llimpiar</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Yá ta executándose una xera d&apos;analís</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 ta analizando la coleición de música.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 ta usando &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; pa catalogar la to música.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Esto llevará un tiempu dependiendo del tamañu de la coleición y de la velocidá de la rede.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Pues tomar un café</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descargando l&apos;anovamientu…</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Suelta equí p&apos;amestar a la llista de reproducción</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artistes</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbumes</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Carpetes</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Dexar de reproducir tres la pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Pista siguiente</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Xubir volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Baxar volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Callar</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Guetar p&apos;alantre</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Guetar p&apos;atrás</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Falló la identificación</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Anicia sesión en %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Nome d&apos;&amp;usuariu:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>Contrase&amp;ña:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Crear una cuenta en %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>¿Escaecisti&apos;l &lt;a href=&apos;%1&apos;&gt;nome d&apos;usuariu&lt;/a&gt; o la &lt;a href=&apos;%2&apos;&gt;contraseña&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Dir a la vista anterior</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Amuesa información de la pista actual</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Ante&amp;rior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Tornar a la pista anterior</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>Siguie&amp;nte</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Saltar a la pista siguiente</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Re&amp;producir</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Aniciar reproducción</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Pasar a pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Desanicia&amp;r</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Desaniciar les pistes esbillaes de la llista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>X&amp;ubir</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Xubir na llista les pistes esbillaes</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Baxar</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Baxar na llista les pistes esbillaes</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Co&amp;lar</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Alón</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Camudar la carpeta de la coleición...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Escoyer una carpeta de coleición de música distinta</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Páxina &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Facer una &amp;donación</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, sofita&apos;l desendolcu continuu de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Tocante &amp;a</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información tocante a %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>Lli&amp;mpiar</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Desaniciar toles pistes de la llista</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Baraxar</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Mou de llista al debalu</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Repetir</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Volver a reproducir la primera canción cuando acaben toes</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar volume</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>Re&amp;producción</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Llista</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Calca %1 pa xubir el volume, %2 pa baxalu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Anovando coleición...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Anovando coleición - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Coleición anovada</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Dexar pan&amp;talla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempu faltante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume silenciáu</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume activu</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Consigui la versión completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versión %2 yá ta disponible.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Avisame más sero</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Anovar</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>A&amp;menorgar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zarrar</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Mercar %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>Parar dempué&amp;s d&apos;esta pista</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Unviar los títulos reproducíos a %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>Co&amp;lar de %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Informar d&apos;un problema...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 acabó d&apos;analizar la coleición de música.</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Soltar equí los oxetos</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Finó la llista</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Esto ye namái la versión demo de %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Te permite reproducir delles pistes pa que puedas probar el programa y ver si te val.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Siguir</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Consiguir la versión completa</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Hai disponible una versión nueva de %1.</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 yá ta disponible. Tienes %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>¿Quies descargala agora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Saltar esta versión</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Recordámelo más sero </translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar anovamientu</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Apegar</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>La versión de prueba ta llendada a sólo %1 pistes na llista de reproducción.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>La llista de reproducción ta balera</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 pistes - La duración total ye %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>La gueta nun tuvo resultaos.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Pistes</translation>
    </message>
</context>
</TS>